@@ -32,7 +32,7 @@
 #' x <- list(1:3, 3:1, 1:4, 4:1, c(1, 2, 4, 6), c(6, 4, 1, 2))
 #' x[distinct(x)]
 distinct <- function(x, N = max(unlist(x))) {
-  pri <- randtoolbox::get.primes(N)
+  pri <- primes100k[seq_len(N)]
   if (capabilities()[["long.double"]]) {
     sums <- sapply(x, function(xi) sum(log(pri[xi])))
   } else {
